@@ -26,7 +26,7 @@ FINISHED_STATUSES = ["completed", "failed", "exception"]
 ALL_STATUSES = FINISHED_STATUSES + ["unscheduled", "pending", "running"]
 STATUS_VALUE = {"exception": 1, "failed": 2, "completed": 3}
 
-GRCOV_INDEX = "gecko.cache.level-3.toolchains.v3.linux64-grcov.latest"
+GRCOV_INDEX = "gecko.cache.level-1.toolchains.v3.linux64-grcov.latest"
 GRCOV_ARTIFACT = "public/build/grcov.tar.zst"
 
 logger = logging.getLogger(__name__)
@@ -302,8 +302,9 @@ def download_grcov():
     os.remove(archive)
 
     # Get version from grcov binary
-    grcov = os.path.join(dest, "grcov")
+    grcov = os.path.join(dest, "grcov", "grcov")
     assert os.path.exists(grcov), "Missing grcov binary"
+    assert os.path.isfile(grcov), "grcov should be a file"
     version = subprocess.check_output([grcov, "--version"]).decode("utf-8")
 
     # Compare version with currently available
@@ -334,7 +335,6 @@ def upload_html_report(
     taskcluster.auth()
 
     for path in Path(report_dir).rglob("*"):
-
         filename = str(path.relative_to(report_dir))
         content_type = magic.from_file(str(path), mime=True)
         logger.debug("Uploading {} as {}".format(filename, content_type))
